<?php
/**
 * @author Amasty Team
 * @copyright Copyright (c) 2016 Amasty (https://www.amasty.com)
 * @package Amasty_Geoip
 */

namespace Amasty\Geoip\Block\Adminhtml\Settings;

class DownloadNImport extends \Magento\Config\Block\System\Config\Form\Field
{

    /**
     * Return element html
     *
     * @param  \Magento\Framework\Data\Form\Element\AbstractElement $element
     * @return string
     *
     * @SuppressWarnings(PHPMD.UnusedFormalParameter)
     */
    public function _getElementHtml(\Magento\Framework\Data\Form\Element\AbstractElement $element)
    {
        $importTypes = array(
            'location',
            'block'
        );

        $urls = [];
        foreach ($importTypes as $type) {
            $startDownloadingUrl = $this->getUrl('amasty_geoip/geoip/startDownloading', array(
                'type' => $type,
                'action' => 'download_and_import'
            ))
            ;

            $startUrl = $this->getUrl('amasty_geoip/geoip/start', array(
                'type' => $type,
                'action' => 'download_and_import'
            ))
            ;

            $processUrl = $this->getUrl('amasty_geoip/geoip/process', array(
                'type' => $type,
                'action' => 'download_and_import'
            ))
            ;

            $commitUrl = $this->getUrl('amasty_geoip/geoip/commit', array(
                'type' => $type,
                'action' => 'download_and_import'
            ))
            ;

            $urls[] = ['start' => $startUrl, 'process' => $processUrl, 'commit' => $commitUrl, 'download' => $startDownloadingUrl];
        }

        $block = $this->getLayout()
            ->createBlock('Amasty\Geoip\Block\Adminhtml\Template')
            ->setTemplate('Amasty_Geoip::download_n_import.phtml')
            ->setConfig(json_encode($urls))
        ;
        $this->setDNIData($block);

        return $block->toHtml();
    }

    public function setDNIData($block) {
        if ($block->geoipHelper->isDone() && $block->geoipHelper->importTableHasData()) {
            $width = 100;
            $completedClass = "end_downloading_completed";
            $importedClass = "end_imported";
            $importDate = $block->_scopeConfig->getValue('amgeoip/import/date_download');
            if (!empty($importDate))
                $importDate = __('Last Imported: ') . $importDate;
        } else {
            $width = 0;
            $completedClass = "end_downloading_not_completed";
            $importedClass = "end_not_imported";
            $importDate = '';
        }
        $block
            ->setWidth($width)
            ->setCompletedClass($completedClass)
            ->setImportedClass($importedClass)
            ->setImportDate($importDate)
        ;
    }
}
